tslumen.report.dashboard package
================================

.. automodule:: tslumen.report.dashboard
   :members:
   :undoc-members:
   :show-inheritance:

tslumen.report.dashboard.base module
------------------------------------

.. automodule:: tslumen.report.dashboard.base
   :members:
   :undoc-members:
   :show-inheritance:


tslumen.report.dashboard.report module
--------------------------------------

.. automodule:: tslumen.report.dashboard.report
   :members:
   :undoc-members:
   :show-inheritance:

tslumen.report.dashboard.sections.features module
-------------------------------------------------

.. automodule:: tslumen.report.dashboard.sections.features
   :members:
   :undoc-members:
   :show-inheritance:

tslumen.report.dashboard.sections.relations module
--------------------------------------------------

.. automodule:: tslumen.report.dashboard.sections.relations
   :members:
   :undoc-members:
   :show-inheritance:

tslumen.report.dashboard.sections.summary module
------------------------------------------------

.. automodule:: tslumen.report.dashboard.sections.summary
   :members:
   :undoc-members:
   :show-inheritance:

tslumen.report.dashboard.sections.timeseries module
---------------------------------------------------

.. automodule:: tslumen.report.dashboard.sections.timeseries
   :members:
   :undoc-members:
   :show-inheritance:
